aboutsummaryrefslogtreecommitdiffstats
path: root/pkg
diff options
context:
space:
mode:
authorAleksandr Nogikh <nogikh@google.com>2024-06-13 20:30:13 +0200
committerAleksandr Nogikh <nogikh@google.com>2024-06-14 08:29:50 +0000
commit286c38bd1ae34870c40986e8ddebfd65d6e5049e (patch)
tree6d183001c80bf66a4f079a3399e6d140480b36ca /pkg
parenta9616ff57d4ef2794b54e02c26315c739ca8bc85 (diff)
pkg/stats: split out pkg/stats/sample
This will reduce the number of dependencies needed for the main syzkaller tools.
Diffstat (limited to 'pkg')
-rw-r--r--pkg/stats/sample/pvalue.go (renamed from pkg/stats/pvalue.go)2
-rw-r--r--pkg/stats/sample/sample.go (renamed from pkg/stats/sample.go)4
-rw-r--r--pkg/stats/sample/sample_test.go (renamed from pkg/stats/sample_test.go)2
3 files changed, 4 insertions, 4 deletions
diff --git a/pkg/stats/pvalue.go b/pkg/stats/sample/pvalue.go
index 9f413f5aa..acfff4bc4 100644
--- a/pkg/stats/pvalue.go
+++ b/pkg/stats/sample/pvalue.go
@@ -1,7 +1,7 @@
// Copyright 2021 syzkaller project authors. All rights reserved.
// Use of this source code is governed by Apache 2 LICENSE that can be found in the LICENSE file.
-package stats
+package sample
// TODO: I didn't find the substitution as of Feb 2023. Let's keep it as is while it works.
import "golang.org/x/perf/benchstat" // nolint:all
diff --git a/pkg/stats/sample_test.go b/pkg/stats/sample/sample_test.go
index 9e88e9f93..ac7845ccf 100644
--- a/pkg/stats/sample_test.go
+++ b/pkg/stats/sample/sample_test.go
@@ -1,7 +1,7 @@
// Copyright 2021 syzkaller project authors. All rights reserved.
// Use of this source code is governed by Apache 2 LICENSE that can be found in the LICENSE file.
-package stats
+package sample
import (
"reflect"
diff --git a/pkg/stats/sample.go b/pkg/stats/sample/sample.go
index 668675fc1..740f9aefe 100644
--- a/pkg/stats/sample.go
+++ b/pkg/stats/sample/sample.go
@@ -1,8 +1,8 @@
// Copyright 2021 syzkaller project authors. All rights reserved.
// Use of this source code is governed by Apache 2 LICENSE that can be found in the LICENSE file.
-// Package stats provides various statistical operations and algorithms.
-package stats
+// Package sample provides various statistical operations and algorithms.
+package sample
import (
"math"